{{- /*
commonlib.cleanup.job will create a cleanup job based on the input resource types and names.
usage in your subchart:
  {{- include "commonlib.cleanup.job" . -}}

example config will be:

xyz:  # <-- your chart name here, which you want to include the cleanup-job with
  cleanup:
    resourceTypesToNamesMap:
      - resourceType: cronjob
        resourceName: infraclassifier-checkpoint-cleaner
      - resourceType: configmap
        resourceName: ic-configmap-checkpoint
    # Other configuration options for the cleanup job go here
    cleanupJob:
      name: <name it something that describes what you're cleaning up>
      enabled: true

      ## override image used for cleanupjob
      ## optional
      # image:
      #   registry: harbor.nsbu.eng.vmware.com/nsx_intelligence_ob/clustering
      #   repository: thirdparty
      #   tag: "v0.1"

      ## optional
      # backoffLimit: 10

      ## optinal
      # activeDeadlineSeconds: 60

      ## optional
      # restartPolicy: OnFailure

      ## optional
      podLabels:
        - other labels
*/}}
{{- define "commonlib.cleanup.job" -}}
{{- if .Values.cleanup.cleanupJob.enabled }}
apiVersion: batch/v1
kind: Job
metadata:
  name: {{ .Values.cleanup.cleanupJob.name | default (printf "%s-cleanup-job" (default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-")) }}
  labels:
    # Default labels
    helm.sh/chart: {{ printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
    app.kubernetes.io/name: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
    app.kubernetes.io/component: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
    app.kubernetes.io/instance: {{ .Release.Name }}
    {{- if .Chart.AppVersion }}
    app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
    {{- end }}
    app.kubernetes.io/managed-by: {{ .Release.Service }}
spec:
  completions: 1
  parallelism: 1
  {{- if .Values.cleanup.backoffLimit }}
  backoffLimit: {{ .Values.cleanup.backoffLimit }}
  {{- end }}
  template:
    metadata:
      labels:
        {{- with .Values.cleanup.cleanupJob.podLabels }}
        {{ toYaml . | indent 8 }}
        {{- end }}
        app.kubernetes.io/name: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
        app.kubernetes.io/component: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
        app.kubernetes.io/instance: {{ .Release.Name }}
        allow-traffic-to-kubeapi: "true"
        allow-traffic-to-dns: "true"
    spec:
      {{- if .Values.cleanup.cleanupJob.activeDeadlineSeconds }}
      activeDeadlineSeconds: {{ .Values.cleanup.cleanupJob.activeDeadlineSeconds }}
      {{- end }}
      # uses the Chart's SA -- we may need to change this if we have to start sprinkling delete perms everywhere
      serviceAccountName: {{ .Values.serviceAccount.name }}
      {{- with .Values.global.imagePullSecrets }}
      imagePullSecrets:
        {{- toYaml . | nindent 8 }}
      {{- end }}
      restartPolicy: {{ .Values.cleanup.cleanupJob.restartPolicy | default "OnFailure" }}
      containers:
        - name: cleaner
          image: {{ include "platform.images.image" ( dict "imageRoot" .Values.global.waitForImage "global" .Values.global ) }}
          imagePullPolicy: IfNotPresent
          command:
            - /bin/bash
            - -c
            - |
              # Collect the status codes from within the resources-to-delete-loop
              set +e
              statuses=()
              {{- range $resource := .Values.cleanup.resourceTypesToNamesMap }}
              resource_type="{{ $resource.resourceType }}"
              resource_name="{{ $resource.resourceName }}"
              namespace="{{ $.Release.Namespace }}"
              cmd="kubectl delete --namespace $namespace --ignore-not-found=true $resource_type $resource_name"
              echo "Running command: $cmd"
              $($cmd)
              status=$?
              statuses+=("$status")
              echo "Status: $status"

              if [ $status -ne 0 ]; then
                  echo "Error: $cmd failed with exit code $status"
              fi
              {{- end }}

              # Re-enable
              set -e

              # Get an overall status, non-zero == an issue, else 0
              overall_status=0
              for status in "${statuses[@]}"; do
                  overall_status=$((overall_status + status))
              done
              exit $overall_status
{{- end }}
{{- end }}
